@@ -1,12 +1,15 @@
 import textwrap
 import pandas as pd
-from lantern import FunctionalBase, Metric
-from typing import Dict
+from lantern import FunctionalBase
+from typing import Dict, Union, Any
+
+# from wire_damage.tools import MapMetric, ReduceMetric, AggregateMetric
 
 
 class MetricTable(FunctionalBase):
     name: str
-    metrics: Dict[str, Metric]
+    metrics: Dict[str, Any]
+    # metrics: Dict[str, Union[MapMetric, ReduceMetric, AggregateMetric]]
 
     class Config:
         arbitrary_types_allowed = True
@@ -18,7 +21,14 @@ class MetricTable(FunctionalBase):
         )
 
     def compute(self):
-        return {name: metric.compute() for name, metric in self.metrics.items()}
+        log_dict = dict()
+        for metric_name, metric in self.metrics.items():
+            metric_value = metric.compute()
+            if isinstance(metric_value, dict):
+                log_dict.update(**metric_value)
+            else:
+                log_dict[metric_name] = metric_value
+        return log_dict
 
     def table(self):
         return "\n".join(
